#
# Conditional build:
%bcond_without	alsa		# ALSA backend
%bcond_without	jack		# JACK backend
%bcond_without	portaudio	# PortAudio backend
%bcond_without	pulseaudio	# PulseAudio backend
%bcond_with	sdl		# SDL2 backend
%bcond_with	sse2		# force use of SSE2 instructions (x86)
%bcond_without	gui		# alsoft-config GUI
%bcond_with	qt4		# Qt 4 instead of Qt 5 for GUI
%ifarch pentium4 x32 %{x8664}
%define	with_sse2	1
%endif
Summary:	Open Audio Library
Summary(pl.UTF-8):	Otwarta Biblioteka Dźwięku
Name:		OpenAL
Version:	1.21.1
Release:	1
License:	LGPL v2+
Group:		Libraries
Source0:	http://openal-soft.org/openal-releases/openal-soft-%{version}.tar.bz2
# Source0-md5:	a936806ebd8de417b0ffd8cf3f48f456
Patch0:		%{name}-pc.patch
Patch1:		%{name}-nosse.patch
URL:		http://www.openal.org/
%{?with_sdl:BuildRequires:	SDL2-devel >= 2}
%{?with_alsa:BuildRequires:	alsa-lib-devel}
BuildRequires:	cmake >= 3.0.2
%{?with_jack:BuildRequires:	jack-audio-connection-kit-devel}
BuildRequires:	libmysofa-devel
BuildRequires:	libstdc++-devel >= 6:5
BuildRequires:	pkgconfig
%{?with_portaudio:BuildRequires:	portaudio-devel}
%{?with_pulseaudio:BuildRequires:	pulseaudio-devel}
BuildRequires:	rpmbuild(macros) >= 1.605
%if %{with gui}
%if %{with qt4}
BuildRequires:	QtCore-devel >= 4.8.0
BuildRequires:	QtGui-devel >= 4.8.0
BuildRequires:	qt4-build >= 4.8.0
%else
BuildRequires:	Qt5Core-devel >= 5
BuildRequires:	Qt5Gui-devel >= 5
BuildRequires:	Qt5Widgets-devel >= 5
BuildRequires:	qt5-build >= 5
%endif
%endif
%{?with_sse2:Requires:	cpuinfo(sse2)}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
OpenAL, the Open Audio Library, is a joint effort to create an open,
vendor-neutral, cross-platform API for interactive, primarily
spatialized audio. OpenAL's primary audience are application
developers and desktop users that rely on portable standards like
OpenGL, for games and other multimedia applications. OpenAL is already
supported by a number of hardware vendors and developers.

%description -l pl.UTF-8
OpenAL, otwarta biblioteka dźwięku, to połączony wysiłek w celu
stworzenia otwartego, niezależnego od producentów, międzyplatformowego
interfejsu projektowania aplikacji w części obsługi dźwięku.
Biblioteka adresowana jest do twórców aplikacji i użytkowników,
którzy wybierają przenośne standardy, jak OpenGL, w grach i
aplikacjach multimedialnych. OpenAL posiada już wsparcie wielu
dostarczycieli sprzętu i programistów.

%package devel
Summary:	Headers for OpenAL
Summary(pl.UTF-8):	Pliki nagłówkowe do OpenAL
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
Header files for OpenAL-based programs.

%description devel -l pl.UTF-8
Pliki nagłówkowe potrzebne przy budowaniu programów opartych na
OpenAL.

%package gui
Summary:	OpenAL configuration GUI
Summary(pl.UTF-8):	Graficzny interfejs do konfiguracji biblioteki OpenAL
Group:		X11/Applications/Sound
Requires:	%{name} = %{version}-%{release}
Requires:	QtCore >= 4.8.0
Requires:	QtGui >= 4.8.0

%description gui
OpenAL configuration GUI.

%description gui -l pl.UTF-8
Graficzny interfejs do konfiguracji biblioteki OpenAL.

%prep
%setup -q -n openal-soft-%{version}
%patch0 -p1
%patch1 -p1

%build
cd build
%cmake .. \
	%{!?with_alsa:-DALSOFT_BACKEND_ALSA=OFF} \
	%{!?with_jack:-DALSOFT_BACKEND_JACK=OFF} \
	%{!?with_portaudio:-DALSOFT_BACKEND_PORTAUDIO=OFF} \
	%{!?with_pulseaudio:-DALSOFT_BACKEND_PULSEAUDIO=OFF} \
	%{?with_sdl:-DALSOFT_BACKEND_SDL2=ON} \
	%{!?with_sse2:-DALSOFT_ENABLE_SSE2_CODEGEN=OFF} \
	-DALSOFT_EXAMPLES=OFF \
	%{!?with_gui:-DALSOFT_NO_CONFIG_UTIL=ON} \
	%{?with_qt4:-DALSOFT_NO_QT5=ON} \

%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_sysconfdir}/openal

%{__make} -C build install \
	DESTDIR=$RPM_BUILD_ROOT

install -p alsoftrc.sample $RPM_BUILD_ROOT%{_sysconfdir}/openal/alsoft.conf

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/openal
%attr(755,root,root) %{_bindir}/makemhr
%attr(755,root,root) %{_bindir}/openal-info
%attr(755,root,root) %{_libdir}/libopenal.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libopenal.so.1
%{_datadir}/openal

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libopenal.so
%{_includedir}/AL
%{_pkgconfigdir}/openal.pc
%{_libdir}/cmake/OpenAL

%if %{with gui}
%files gui
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/alsoft-config
%endif
%changelog
* Sat Feb 06 2021 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/OpenAL.git;a=log;h=master

* Fri Feb 05 2021 Jan Palus <atler@pld-linux.org> fa0d858
- up to 1.21.1

* Thu Nov 05 2020 Jakub Bogusz <qboosh@pld-linux.org> 27bdd11
- enhanced nosse patch

* Wed Nov 04 2020 Jan Palus <atler@pld-linux.org> edbd7ed
- remove unused patches dropped from spec in 7e80d8d

* Wed Nov 04 2020 Jan Palus <atler@pld-linux.org> 94a1f14
- up to 1.21.0

* Wed Mar 11 2020 Jakub Bogusz <qboosh@pld-linux.org> c41d0d6
- release 2 (libmysofa soname change)

* Fri Jan 24 2020 Jan Palus <atler@pld-linux.org> 14419c3
- up to 1.20.1

* Wed Dec 04 2019 Jakub Bogusz <qboosh@pld-linux.org> b90768b
- ALSOFT_CPUEXT_* are safe (runtime detected); but ALSOFT_ENABLE_SSE2_CODEGEN makes sse2 obligatory
- added nosse patch to allow build on x86 with ALSOFT_ENABLE_SSE2_CODEGEN disabled
- release 2

* Tue Dec 03 2019 Jan Palus <atler@pld-linux.org> 2b67cb4
- BR: libmysofa-devel

* Tue Dec 03 2019 Jan Palus <atler@pld-linux.org> 4d244e7
- use different cmake flags to toggle sse

* Mon Dec 02 2019 Jan Palus <atler@pld-linux.org> 996f154
- up to 1.20.0

* Thu Jul 25 2019 Jakub Bogusz <qboosh@pld-linux.org> 60781cc
- added pc patch (support absolute CMAKE_INSTALL_*DIR); release 2

* Mon Nov 19 2018 Jakub Bogusz <qboosh@pld-linux.org> bd9b58b
- new Source0 URL, updated to 1.19.1

* Sat Sep 08 2018 Jan Palus <atler@pld-linux.org> 9698781
- up to 1.19.0

* Wed Nov 15 2017 Jan Palus <atler@pld-linux.org> 65d19d9
- up to 1.18.2

* Tue Jun 06 2017 Jakub Bogusz <qboosh@pld-linux.org> 60652dc
- rpm macros for cmake

* Tue Jun 06 2017 Jakub Bogusz <qboosh@pld-linux.org> 99cf5ae
- updated to 1.18.0
- now defaults to Qt5
- MIDI support was dropped some time ago

* Fri Jan 29 2016 Jakub Bogusz <qboosh@pld-linux.org> 9c65cf3
- updated to 1.17.2

* Sun Dec 13 2015 Jakub Bogusz <qboosh@pld-linux.org> 4fafbfa
- updated to 1.17.1

* Wed Nov 25 2015 Jakub Bogusz <qboosh@pld-linux.org> b5f2479
- updated to 1.17.0

* Sun Mar 15 2015 Jakub Bogusz <qboosh@pld-linux.org> f2c99d8
- updated to 1.16.0

